pigz version 2.7
diff --git a/README b/README
index 7791744..31f25dd 100644
--- a/README
+++ b/README
@@ -1,4 +1,4 @@
-pigz 2.6 (6 Feb 2021) by Mark Adler
+pigz 2.7 (15 Jan 2022) by Mark Adler
 
 pigz, which stands for Parallel Implementation of GZip, is a fully functional
 replacement for gzip that exploits multiple processors and multiple cores to
diff --git a/pigz.1 b/pigz.1
index a2f700b..c4352e1 100644
--- a/pigz.1
+++ b/pigz.1
@@ -1,4 +1,4 @@
-.TH PIGZ 1 "February 6, 2021"
+.TH PIGZ 1 "January 15, 2022"
 .SH NAME
 pigz, unpigz \- compress or expand files
 .SH SYNOPSIS
@@ -242,4 +242,4 @@
 warranty.  In no event will the author be held liable for any damages
 arising from the use of this software.
 .PP
-Copyright (C) 2007-2021 Mark Adler <madler@alumni.caltech.edu>
+Copyright (C) 2007-2022 Mark Adler <madler@alumni.caltech.edu>
diff --git a/pigz.pdf b/pigz.pdf
index cdb11c7..8df3112 100644
--- a/pigz.pdf
+++ b/pigz.pdf
Binary files differ
diff --git a/pigz.spec b/pigz.spec
index 5ebd1ac..4712abb 100644
--- a/pigz.spec
+++ b/pigz.spec
@@ -1,6 +1,6 @@
 Summary: pigz is a parallel implementation of gzip which utilizes multiple cores
 Name: pigz
-Version: 2.6
+Version: 2.7
 Release: 1
 Source0: %{name}-%{version}.tar.gz
 License: zlib
diff --git a/pigz.c b/pigz.c
index 2d1ef48..01e50e0 100644
--- a/pigz.c
+++ b/pigz.c
@@ -1,6 +1,6 @@
 /* pigz.c -- parallel implementation of gzip
  * Copyright (C) 2007-2021 Mark Adler
  * Version 2.6  6 Feb 2021  Mark Adler
  */
 
 /*
@@ -198,9 +198,16 @@
    2.6     6 Feb 2021  Add --huffman/-H and --rle/U strategy options
                        Fix issue when compiling for no threads
                        Fail silently on a broken pipe
+   2.7    15 Jan 2022  Show time stamp only for the first gzip member
+                       Show totals when listing more than one gzip member
+                       Don't unlink input file if it has other links
+                       Add documentation for environment variables
+                       Fix bug when combining -l with -d
+                       Exit with status of zero if skipping non .gz files
+                       Permit Huffman only (-H) when not compiling with zopfli
  */
 
-#define VERSION "pigz 2.6"
+#define VERSION "pigz 2.7"
 
 /* To-do:
     - make source portable for Windows, VMS, etc. (see gzip source code)
@@ -4471,7 +4478,7 @@
             case 'K':  g.form = 2;  g.sufx = ".zip";  break;
             case 'L':
                 puts(VERSION);
-                puts("Copyright (C) 2007-2021 Mark Adler");
+                puts("Copyright (C) 2007-2022 Mark Adler");
                 puts("Subject to the terms of the zlib license.");
                 puts("No warranty is provided or implied.");
                 exit(0);
@@ -1,6 +1,6 @@
 /* pigz.c -- parallel implementation of gzip
- * Copyright (C) 2007-2021 Mark Adler
- * Version 2.6  6 Feb 2021  Mark Adler
+ * Copyright (C) 2007-2022 Mark Adler
+ * Version 2.7  15 Jan 2022  Mark Adler
  */
 